@@ -105,6 +105,7 @@ def semanticate(xhtml: str) -> str:
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))\b([1-4]D)\b", r"""<abbr epub:type="z3998:initialism">\1</abbr>""", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(Thos\.|Jas\.|Chas\.|Wm\.)", r"""<abbr epub:type="z3998:given-name">\1</abbr>""", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([ap])\.\s?m\.", r"<abbr>\1.m.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(4to|8vo|12mo|16mo|18mo|32mo|48mo|64mo)(?:\.(\s+\p{Lowercase_Letter}))?", r"<abbr>\1</abbr>\2", xhtml) # Book sizes
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([0-9]{1,2})\s?[Aa]\.?\s?[Mm](?:\.|\b)", r"\1 <abbr>a.m.</abbr>", xhtml)
 	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([0-9]{1,2})\s?[Pp]\.?\s?[Mm](?:\.|\b)", r"\1 <abbr>p.m.</abbr>", xhtml)
 	# this should be placed after the am/pm test, to prevent tagging just the p. in "p. m."
@@ -144,7 +145,7 @@ def semanticate(xhtml: str) -> str:
 	xhtml = regex.sub(r"""([^\p{Letter}>\"])([vxVX])(\b[^\-]|st\b|nd\b|rd\b|th\b)""", r"""\1<span epub:type="z3998:roman">\2</span>\3""", xhtml)
 
 	# We can assume a lowercase i is always a Roman numeral unless followed by ’
-	xhtml = regex.sub(r"""([^\p{Letter}<>/\"])i\b(?!’)""", r"""\1<span epub:type="z3998:roman">i</span>""", xhtml)
+	xhtml = regex.sub(r"""([^\p{Letter}<>/\"])i\b(?!’)(?![^<>]+>)""", r"""\1<span epub:type="z3998:roman">i</span>""", xhtml)
 
 	# Fix obscured names starting with I, V, or X
 	xhtml = regex.sub(fr"""<span epub:type="z3998:roman">([IVX])</span>{se.WORD_JOINER}⸺""", fr"""\1{se.WORD_JOINER}⸺""", xhtml)
@@ -839,7 +840,8 @@ def _format_css_component_list(content: list, in_selector=False, in_paren_block=
 			if token.representation == "0":
 				output += "0"
 			else:
-				output += token.representation + token.lower_unit
+				# Remove leading 0 from dimensions
+				output += token.representation.lstrip("0") + token.lower_unit
 
 		if token.type == "number":
 			output += token.representation
@@ -863,7 +865,7 @@ def _format_css_component_list(content: list, in_selector=False, in_paren_block=
 			output += f"#{token.value}"
 
 		if token.type == "string":
-			output += f"\"{token.value}\""
+			output += token.representation
 
 		if token.type == "() block":
 			output += f"({_format_css_component_list(token.content, in_selector, True)})"
@@ -888,7 +890,7 @@ def _format_css_component_list(content: list, in_selector=False, in_paren_block=
 	# Here we try to re-add spaces after a : if it's within a paren block.
 	# We could do this during parsing but we would need to peek ahead to the next item in the loop which
 	# is too much trouble right now.
-	output = regex.sub(r"\(([^\"\s]+?):([^\"\s]+?)", r"(\1: \2", output)
+	output = regex.sub(r"\(([^\"\s)]+?):([^\"\s]+?)", r"(\1: \2", output)
 
 	return output.strip()
 
