@@ -182,6 +182,16 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 				with importlib.resources.files("se.data.templates").joinpath("proofreading.css").open("r", encoding="utf-8") as proofreading_css_file:
 					local_css_file.write("\n" + proofreading_css_file.read())
 
+			# Wrap no-break hyphens and no-break spaces in a class that will colorize them when proofing.
+			for file_path in work_compatible_epub_dir.glob("**/*.xhtml"):
+				with open(file_path, "r+", encoding="utf-8") as file:
+					xhtml = file.read()
+
+					xhtml = regex.sub(fr"([{se.NO_BREAK_HYPHEN}{se.NO_BREAK_SPACE}])", r"""<span class="proofreading">\1</span>""", xhtml)
+					file.seek(0)
+					file.write(se.formatting.simplify_css(xhtml))
+					file.truncate()
+
 		# Update the release date in the metadata and colophon
 		if self.last_commit:
 			for file_path in work_compatible_epub_dir.glob("**/*.xhtml"):
@@ -561,7 +571,7 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 					processed_css = regex.sub(r"(\s+)page-break-(before|after):\s+page;", "\\1page-break-\\2: always;", processed_css)
 
 					# Replace `vw` or `vh` units with percent, a reasonable approximation
-					processed_css = regex.sub(r"([0-9\.]+\s*)v(w|h);", r"\1%;", processed_css)
+					processed_css = regex.sub(r"^(.+?:\s*[0-9\.]+\s*)(v(w|h));", r"\1%;\n\1\2;", processed_css, flags=regex.MULTILINE)
 
 					if processed_css != css:
 						file.seek(0)
@@ -843,10 +853,6 @@ def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_k
 				processed_css = regex.sub(r"^\s*hyphens\s*:\s*(.+)", "\thyphens: \\1\n\tadobe-hyphenate: \\1\n\t-webkit-hyphens: \\1\n\t-moz-hyphens: \\1", processed_css, flags=regex.MULTILINE)
 				processed_css = regex.sub(r"^\s*hyphens\s*:\s*none;", "\thyphens: none;\n\tadobe-text-layout: optimizeSpeed; /* For Nook */", processed_css, flags=regex.MULTILINE)
 
-				# We add a 20vh margin to sections without heading elements to drop them down on the page a little.
-				# As of 01-2021 the vh unit is not supported on Nook or Kindle (but is on kepub and ibooks).
-				processed_css = regex.sub(r"^(\s*)margin-top\s*:\s*20vh;", r"\1margin-top: 5em;", processed_css, flags=regex.MULTILINE)
-
 				# We converted svgs to pngs, so replace references
 				processed_css = regex.sub(r"""url\("(.*?)\.svg"\)""", r"""url("\1.png")""", processed_css)
 
